@@ -384,6 +384,12 @@ where
         self
     }
 
+    /// Set the added vocabulary.
+    pub fn with_added_vocabulary(mut self, added_vocabulary: AddedVocabulary) -> Self {
+        self.added_vocabulary = added_vocabulary;
+        self
+    }
+
     /// Set the trunaction parameters.
     #[must_use]
     pub fn with_truncation(mut self, trunc: Option<TruncationParams>) -> Self {
@@ -598,6 +604,17 @@ where
         &self.model
     }
 
+    /// Set the added vocabulary.
+    pub fn with_added_vocabulary(&mut self, added_vocabulary: AddedVocabulary) -> &mut Self {
+        self.added_vocabulary = added_vocabulary;
+        self
+    }
+
+    /// Get the added vocabulary
+    pub fn get_added_vocabulary(&self) -> &AddedVocabulary {
+        &self.added_vocabulary
+    }
+
     /// Set the truncation parameters
     ///
     /// Fails if `stride` is too high relative to `max_length` and `post_processor.added_tokens()`
@@ -911,7 +928,6 @@ where
         pretokenized: P,
     ) -> Result<PreTokenizedString> {
         let mut pretokenized: PreTokenizedString = pretokenized.into();
-
         if let Some(ref pretok) = self.pre_tokenizer {
             pretok.pre_tokenize(&mut pretokenized)?;
         }
